@@ -12,7 +12,10 @@ from .logger import logger
 
 from .metadata import lookup_file_metadata, lookup_file_derivative_path
 from .files import canonical_item_filename
+from .const import PB_ITEM
 
+IMAGE_TYPES = ['jp2', 'jpg', 'tif']
+ARCHIVE_TYPES = ['zip', 'tar']
 
 def get_imagestack_info_from_format(fmt):
     """
@@ -77,6 +80,29 @@ def get_imagestack_info_for_file(filename, files_metadata):
     return info
 
 
+def find_imagestack_for_prefix(basefilename, files_metadata):
+    """
+    Probe for an imagestack in an item give the file base filename. (i.e.
+    everything before _jp2.zip, _hocr.html, _djvu.xml, etc)
+
+    Args:
+
+    * basefilename (str): Base filename
+    * files_metadata: files metadata as returned by `load_files_metadata`.
+
+    Returns: imagestack info (per `get_imagestack_info_for_file`) or None
+    """
+    for image_type in IMAGE_TYPES:
+        for archive_type in ARCHIVE_TYPES:
+            path = basefilename + '_%s.%s' % (image_type, archive_type)
+            try:
+                return get_imagestack_info_for_file(path, files_metadata)
+            except ValueError:
+                pass
+
+    return None
+
+
 def get_source_image_stack_for_file(source_file, files_metadata):
     """
     Find the source image stack for a given source_file, by searching the files
